@@ -2,9 +2,10 @@
 #' @description
 #' The BioTIMEr package is developed in GitHub
 #' (https://github.com/bioTIMEHub/BioTIMEr). To see the preferable citation of
-#' the package, type citation("BioTIMEr"). The associated vignette includes an introduction
-#' to the functions, how to apply them as well as some hints on how to
-#' quantify and visualise temporal biodiversity change for a given BioTIME dataset.
+#' the package, type citation("BioTIMEr"). The associated vignette includes an
+#' introduction to the functions, how to apply them as well as some hints on how
+#' to quantify and visualise temporal biodiversity change for a given BioTIME
+#' dataset.
 #'
 "_PACKAGE"
 .datatable.aware <- TRUE
@@ -25,7 +26,8 @@ utils::globalVariables(c(
   "resamp",
   "metric",
   "intercept",
-  "pvalue"
+  "pvalue",
+  "temporary_column"
 ))
 ## usethis namespace: end
 NULL
