@@ -6,15 +6,18 @@
 #' Scale construction for ggplot use
 #' @rdname BioTIME-palette
 #' @export
-#' @param palette One of: `realms`, `gradient`, `cool`, `warm`, default to `realms`.
+#' @param palette One of: `realms`, `gradient`, `cool`, `warm`, default to
+#' `realms`.
 #' @param discrete See Details. default to `FALSE`
 #' @param reverse Default to `FALSE`
-#' @param ... Passed to \code{\link[ggplot2]{discrete_scale}} or \code{\link[ggplot2]{scale_color_gradient}}
-#' @returns If \code{discrete} is \code{TRUE}, the function returns a colour palette produced by
-#'     \code{\link[ggplot2]{discrete_scale}} and if \code{discrete} is \code{FALSE}, the function
-#'     returns a colour palette produced by \code{\link[ggplot2]{scale_color_gradient}}.
-#' @details
-#' USAGE NOTE: Remember to change these arguments when plotting colours continuously.
+#' @param ... Passed to \code{\link[ggplot2]{discrete_scale}} or
+#' \code{\link[ggplot2]{scale_color_gradient}}
+#' @returns If \code{discrete} is \code{TRUE}, the function returns a colour
+#'     palette produced by \code{\link[ggplot2]{discrete_scale}} and if
+#'     \code{discrete} is \code{FALSE}, the function returns a colour palette
+#'     produced by \code{\link[ggplot2]{scale_color_gradient}}.
+#' @details USAGE NOTE: Remember to change these arguments when plotting colours
+#' continuously.
 #' @author Cher F. Y. Chow
 #' @importFrom ggplot2 discrete_scale
 #' @importFrom ggplot2 scale_fill_gradientn
@@ -47,14 +50,18 @@ scale_colour_biotime <- scale_color_biotime
 
 #' Scale construction for filling in ggplot
 #' @rdname BioTIME-palette
-#' @returns If \code{discrete} is \code{TRUE}, the function returns a colour palette produced by
-#'     \code{\link[ggplot2]{discrete_scale}} and if \code{discrete} is \code{FALSE}, the function
-#'     returns a colour palette produced by \code{\link[ggplot2]{scale_color_gradient}}.
-#' @export
+#'
 #' @inherit scale_color_biotime author
 #' @inherit scale_color_biotime details
+#'
+#' @returns If \code{discrete} is \code{TRUE}, the function returns a colour
+#'     palette produced by \code{\link[ggplot2]{discrete_scale}} and if
+#'     \code{discrete} is \code{FALSE}, the function returns a colour palette
+#'     produced by \code{\link[ggplot2]{scale_color_gradient}}.
+#'
 #' @importFrom ggplot2 discrete_scale
 #' @importFrom ggplot2 scale_fill_gradientn
+#' @export
 
 scale_fill_biotime <- function(
   palette = "realms",
@@ -102,21 +109,27 @@ intPalette <- function(colors, ...) {
     checkmate::assert_integerish(n, lower = 1L)
     if (n > length(colors)) {
       x <- ramp(seq.int(0, 1, length.out = n))
-      if (ncol(x) == 4L)
+      if (ncol(x) == 4L) {
         grDevices::rgb(
           x[, 1L],
           x[, 2L],
           x[, 3L],
           x[, 4L],
           maxColorValue = 255
-        ) else grDevices::rgb(x[, 1L], x[, 2L], x[, 3L], maxColorValue = 255)
-    } else
-      colors[sort(sample(x = c(1:length(colors)), size = n, replace = FALSE))]
+        )
+      } else {
+        grDevices::rgb(x[, 1L], x[, 2L], x[, 3L], maxColorValue = 255)
+      }
+    } else {
+      colors[sort(sample(x = c(seq_along(colors)), size = n, replace = FALSE))]
+    }
   }
 }
 
 biotime_cols <- function(palette = "gradient", reverse = FALSE, ...) {
   pal <- biotime_palettes[[palette]]
-  if (reverse) pal <- rev(pal)
+  if (reverse) {
+    pal <- rev(pal)
+  }
   intPalette(pal, ...) # interpolates palette colours
 }
