@@ -2,10 +2,28 @@
 meta <- base::readRDS(testthat::test_path("testdata", "data-meta.rds"))
 btf <- base::readRDS(testthat::test_path("testdata", "data-query.rds"))
 
-result <- gridding(meta, btf)
+test_that("gridding returns an object of same class as meta", {
+  expect_no_error(resdf <- gridding(meta, btf))
+  expect_s3_class(resdf, "data.frame")
 
-test_that("gridding returns a data frame", {
-  expect_s3_class(result, "data.frame")
+  expect_no_error(
+    restbl <- gridding(meta |> dplyr::as_tibble(), btf |> dplyr::as_tibble())
+  )
+  expect_s3_class(
+    restbl,
+    c("tbl_df", "tbl", "data.frame")
+  )
+
+  expect_no_error(
+    resdt <- gridding(
+      meta |> data.table::as.data.table(),
+      btf |> data.table::as.data.table()
+    )
+  )
+  expect_s3_class(
+    resdt,
+    c("data.table", "data.frame")
+  )
 })
 
 test_that("gridding returns the expected columns", {
@@ -32,7 +50,7 @@ test_that("gridding returns the expected columns", {
     "resolution"
   )
   checkmate::expect_names(
-    x = colnames(result),
+    x = colnames(gridding(meta, btf)),
     what = "colnames",
     permutation.of = expected_cols
   )
@@ -40,27 +58,46 @@ test_that("gridding returns the expected columns", {
 
 test_that("gridding returns correct number of rows", {
   expected_rows <- nrow(btf)
-  expect_equal(nrow(result), expected_rows)
+  expect_equal(nrow(gridding(meta, btf)), expected_rows)
 })
 
 test_that("gridding creates correct cell IDs", {
-  checkmate::expect_integer(result$cell, any.missing = FALSE, lower = 0L)
+  checkmate::expect_double(
+    x = gridding(meta, btf)$cell,
+    any.missing = FALSE,
+    lower = 0,
+    null.ok = FALSE
+  )
 })
 
 test_that("gridding produces consistent results", {
   skip_on_ci()
   skip_on_cran()
-  expect_snapshot(result)
+
+  expect_snapshot(gridding(meta, btf))
 })
 
 test_that("gridding respects provided res parameter", {
   skip_on_ci()
   skip_on_cran()
+
   expect_snapshot(gridding(meta, btf, res = 18))
 })
 
 test_that("gridding respects resByData argument", {
   skip_on_ci()
   skip_on_cran()
+
   expect_snapshot(gridding(meta, btf, resByData = TRUE))
 })
+
+# test_that("gridding correctly manages data.table objects", {
+#   skip_on_ci()
+#   skip_on_cran()
+
+#   data.table::setDT(meta)
+#   data.table::setDT(btf)
+
+#   result <- gridding(meta, btf, res = 12, resByData = FALSE)
+#   expect_snapshot(result)
+# })
